==> haskell-x509-validation-1.6.11-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-validation
version:              1.6.11
visibility:           public
id:                   x509-validation-1.6.11-AdwzboWgBd8EuBEkqm6Q6p
key:                  x509-validation-1.6.11-AdwzboWgBd8EuBEkqm6Q6p
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  a89908ca87f651aacc5f3ceb91bd9465
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:          /usr/lib/ghc-8.10.3/site-local/x509-validation-1.6.11
library-dirs:         /usr/lib/ghc-8.10.3/site-local/x509-validation-1.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/x509-validation-1.6.11
hs-libraries:         HSx509-validation-1.6.11-AdwzboWgBd8EuBEkqm6Q6p
depends:
    asn1-encoding-0.9.6-KqGb5VuvVLBAdkUIT26Vn
    asn1-types-0.3.4-1fX7Cp5EHNDBwz7gqfkUvy base-4.14.1.0
    bytestring-0.10.12.0 containers-0.6.2.1
    cryptonite-0.27-DvcguMTH5e8DHN6L8PACh6
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    hourglass-0.2.12-6a091O0yhuJ6fpzz8qA716
    memory-0.15.0-E8yvrlcxsw5JtBytoHmuPe mtl-2.2.2
    pem-0.2.4-2WrmcHlXxf33VKwkfq7mMp x509-1.7.5-ApkdCoyMDAt84Mqx99GodN
    x509-store-1.6.7-IrhKTX2pYPZFiTAPXLeigD

haddock-interfaces:
    /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-validation-1.6.11-118-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-validation.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-validation
version:              1.6.11
visibility:           public
id:                   x509-validation-1.6.11-ErR6X5tgDm48PthDugI7Vj
key:                  x509-validation-1.6.11-ErR6X5tgDm48PthDugI7Vj
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X.509 Certificate and CRL validation
description:          X.509 Certificate and CRL validation. please see README
category:             Data
abi:                  623311cbee7dddb8e5d89fa427bfabd2
exposed:              True
exposed-modules:      Data.X509.Validation
hidden-modules:
    Data.X509.Validation.Signature Data.X509.Validation.Fingerprint
    Data.X509.Validation.Cache Data.X509.Validation.Types

import-dirs:          /usr/lib/ghc-8.10.3/site-local/x509-validation-1.6.11
library-dirs:         /usr/lib/ghc-8.10.3/site-local/x509-validation-1.6.11
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.3/x509-validation-1.6.11
hs-libraries:         HSx509-validation-1.6.11-ErR6X5tgDm48PthDugI7Vj
depends:
    asn1-encoding-0.9.6-2kU63py5zGHB6hZWVrrt4t
    asn1-types-0.3.4-8EHYB51iZYEf0YINTzDFz base-4.14.1.0
    bytestring-0.10.12.0 containers-0.6.2.1
    cryptonite-0.28-KKXZTeZ4Ne6Hp3IxvdQ1Rp
    data-default-class-0.1.2.0-56BXPST0gStFZdhRwxhsn8
    hourglass-0.2.12-2EBqXgXD8ZZ4qlnZUCbX11
    memory-0.15.0-E8yvrlcxsw5JtBytoHmuPe mtl-2.2.2
    pem-0.2.4-44ktQFlArPxF9MEbiT6syS x509-1.7.5-LwVgN45WtgGEFNb8Gu25YC
    x509-store-1.6.7-IW5wo11D5FeIS4ZPxsufbv

haddock-interfaces:
    /usr/share/doc/haskell-x509-validation/html/x509-validation.haddock

haddock-html:         /usr/share/doc/haskell-x509-validation/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
